import Link from "next/link";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";
import PageTitle from "../components/PageTitle";
import Head from "next/head";
import Container from "../components/Container";
import useLanguage from "../hooks/useLanguage";
import { useDispatch } from "react-redux";
import { authModalSet } from "../app/features/auth/authSlice";
import { useBecomeCompanyMutation } from "../app/features/auth/apiSlice";
function BecomeCompany() {
  const router = useRouter();
  const [data, setData] = useState({
    name_of_company: "",
    director_full_name: "",
    tin: "",
    legal_address: "",
    warehouse_address: "",
    telephone: "",
    bank: "",
    checking_account: "",
    mfo: "",
    oked: "",
    vat_payer_code: "",
    contact_person: "",
    order_type: "",
    received_location: "",
    received_date: "",
  });

  useEffect(() => {
    setData((prev) => ({
      ...prev,
      order_type: router.query.order_type,
      received_location: router.query.received_location,
      received_date: router.query.received_date,
    }));
  }, [router.query]);

  const textHandler = (e) => {
    setData((prev) => ({ ...prev, [e.target.name]: e.target.value }));
  };
  textHandler.bind(this);

  // handle submit
  const [becomeCompany] = useBecomeCompanyMutation();
  const handleSubmit = (e) => {
    e.preventDefault();
    becomeCompany({
      data: data,
      redirect: () => router.push("/cart"),
    });
  };

  handleSubmit.bind(this);
  const language = useLanguage();
  return (
    <>
      <Head>
        <title className="notranslate">{language["Become a Company"]}</title>
      </Head>
      <PageTitle
        title={language["Become a Company"]}
        pageName={language["Become a Company"]}
      />
      <section className="lg:py-20 py-3 bg-slate-50 ">
        <Container>
          <div className="grid grid-cols-1 lg:grid-cols-12 bg-white p-3 sm:p-[30px] gap-12">
            <div className="lg:col-span-12">
              <div className="w-full mb-4">
                <h1 className="text-[22px] font-semibold text-slate-900 mb-1 notranslate">
                  {language["Company Information"]}
                </h1>
                <p className="text-[15px] text-slate-400 notranslate">
                  {
                    language[
                      "Fill the form below or write us We will help you as soon as possible"
                    ]
                  }
                </p>
              </div>
              <div className=" w-full h-full">
                <form
                  className=" grid grid-cols-2 gap-10"
                  onSubmit={handleSubmit}
                >
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate "
                      for="name_of_company"
                    >
                      {language["Name of Company"]}*
                    </label>
                    <input
                      placeholder="Name of Company"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="name_of_company"
                      name="name_of_company"
                      value={data.name_of_company}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="full_name_of_the_director"
                    >
                      {language["Full name of the director"]}*
                    </label>
                    <input
                      placeholder="full_name_of_the_director"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="full_name_of_the_director"
                      name="director_full_name"
                      value={data.director_full_name}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="tin"
                    >
                      {language["TIN of the Organization"]}*
                    </label>
                    <input
                      placeholder="TIN of the Organization"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="tin"
                      name="tin"
                      value={data.tin}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="legal_address"
                    >
                      {language["Legal Address"]}*
                    </label>
                    <input
                      placeholder="Legal Address"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="legal_address"
                      name="legal_address"
                      value={data.legal_address}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="warehouse_address"
                    >
                      {language["Warehouse Address"]}*
                    </label>
                    <input
                      placeholder="Warehouse Address"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="warehouse_address"
                      name="warehouse_address"
                      value={data.warehouse_address}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="telephone"
                    >
                      {language["Telephone"]}*
                    </label>
                    <input
                      placeholder="+0099009900"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="telephone"
                      name="telephone"
                      value={data.telephone}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="bank"
                    >
                      {language["Bank"]}*
                    </label>
                    <input
                      placeholder="Bank"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="bank"
                      name="bank"
                      value={data.bank}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="checking_account"
                    >
                      {language["Checking Account"]}*
                    </label>
                    <input
                      placeholder="Checking Account"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="checking_account"
                      name="checking_account"
                      value={data.checking_account}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="mfo"
                    >
                      {language["MFO (Bank Identification Code)"]}*
                    </label>
                    <input
                      placeholder="MFO (Bank Identification Code)"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="mfo"
                      name="mfo"
                      value={data.mfo}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="oked"
                    >
                      {language["OKED (Classification of Economic Activities)"]}
                      *
                    </label>
                    <input
                      placeholder="OKED (Classification of Economic Activities)"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="oked"
                      name="oked"
                      value={data.oked}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="vat_payer_code"
                    >
                      {language["VAT Payer Code"]}*
                    </label>
                    <input
                      placeholder="VAT Payer Code"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="vat_payer_code"
                      name="vat_payer_code"
                      value={data.vat_payer_code}
                      onChange={textHandler}
                    />
                  </div>
                  <div>
                    <label
                      className="capitalize block  mb-2 text-gray-500 text-[13px] font-normal notranslate"
                      for="contact_person"
                    >
                      {language["Contact Person (full name, tel.)"]}*
                    </label>
                    <input
                      placeholder="Contact Person (full name, tel.)"
                      className="input-field placeholder:text-sm text-sm px-6 text-gray-500 w-full font-normal bg-white focus:ring-0 focus:outline-none h-[50px] rounded border border-gray-100 mt-1"
                      type="text"
                      id="contact_person"
                      name="contact_person"
                      value={data.contact_person}
                      onChange={textHandler}
                    />
                  </div>
                  <div className="col-span-2">
                    <div className="w-full flex justify-center">
                      <button
                        type="submit"
                        className="mt-6 self-center bg-dark-300 text-white font-medium text-base py-4 px-8  rounded-lg text-center inline-block transition hover:bg-dark-300/90 w-full max-w-[500px] notranslate"
                      >
                        {language["Become a Company"]}
                      </button>
                    </div>
                    <div className="flex w-full justify-center notranslate mt-3">
                      <a className="/" href="#" target="blank">
                        {language["Already have an Account?Log In"]}
                      </a>
                    </div>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </Container>
      </section>
    </>
  );
}
export default BecomeCompany;
